#########
TODO list
#########

Client
======

+ Implement a "collection" model object for working with paginated lists of
  results.
+ Impelement a way to authenticate or refresh tokens as transparently as
  possible.
+ Need a way to differentiate authentication methods by way of plugins.

CLI
===

+ Implement dotfile for storing user defaults and API token information.
+ Add ``--no-header`` for text-processing tools when dispalying tabulated results.
+ Need a way to differentiate authentication methods by way of plugins.
